@@ -27,34 +27,23 @@ class IngestedSpectrum(Spectrum1D):
     An ingested spectrum is one which is a slightly modified version of an L1 spectrum
     """
     is_template = True
-    parents = [APS]
-    products = ['flux', 'error', 'wvl']
+    children = []  # gets rid of inherited wvl array
+    products = ['flux', 'error', 'wvl', 'ivar', 'logwvl', 'goodpix']
 
 
 class UncombinedIngestedSpectrum(IngestedSpectrum):
-    parents = [L1Spectrum, APS]
-    identifier_builder = ['l1_spectrum', 'aps']
-
-
-class IvarIngestedSpectrum(UncombinedIngestedSpectrum):
-    products = ['flux', 'ivar', 'wvl']
+    parents = [L1Spectrum]
+    identifier_builder = ['l1_spectrum']
 
 
 class CombinedIngestedSpectrum(IngestedSpectrum):
-    parents = [Multiple(L1Spectrum, 1, 3), APS]
-    identifier_builder = ['l1_spectra', 'aps']
-
-
-class IvarCombinedIngestedSpectrum(CombinedIngestedSpectrum):
-    products = ['flux', 'ivar', 'wvl']
-
-
-class MaskedCombinedIngestedSpectrum(CombinedIngestedSpectrum):
-    products = ['flux', 'error', 'logwvl', 'goodpix']
+    parents = [Multiple(L1Spectrum, 1, 3)]
+    identifier_builder = ['l1_spectra']
 
 
 class ModelSpectrum(Spectrum1D):
     is_template = True
+    children = []  # gets rid of inherited wvl array
     parents = [OneOf(IngestedSpectrum, one2one=True)]
     identifier_builder = ['ingested_spectrum']
     products = ['flux']
@@ -65,33 +54,52 @@ class UncombinedModelSpectrum(ModelSpectrum):
     identifier_builder = ['uncombined_ingested_spectrum']
 
 
-class CombinedModelSpectrum(ModelSpectrum):
+class BaseCombinedModelSpectrum(ModelSpectrum):
+    is_template = True
     parents = [OneOf(CombinedIngestedSpectrum, one2one=True)]
     identifier_builder = ['combined_ingested_spectrum']
 
 
+class CombinedModelSpectrum(BaseCombinedModelSpectrum):
+    is_template = False
+
+
 # This allows us to use 'clean' to talk about the clean model or clean spectrum
 # IngestedSpectrum->ModelSpectrum->CleanModelSpectrum
 # IngestedSpectrum->CleanIngestedSpectrum
 
-class GandalfSpectrum(Spectrum1D):
+class GandalfSpectrum(ModelSpectrum):
+    """template object that only stores model flux and sources the wavelength array from another linked object"""
     is_template = True
+    parents = []  # removes input spectrum dependency
+    identifier_builder = None
 
 
-class GandalfModelSpectrum(CombinedModelSpectrum, GandalfSpectrum):
+class GandalfModelSpectrum(BaseCombinedModelSpectrum, GandalfSpectrum):
+    """
+    A Gandalf model spectrum is the full modelled SED of emission lines and continuum
+    It also has:
+        - `.clean_model`     : a clean model spectrum without emission line contribution
+        - `.clean_observed`  : the observed spectrum with model emission lines subtracted
+        - `.emission_line_model`  : the model emission line contribution only
+    """
+
+class GandalfDerivativeSpectrum(GandalfSpectrum):
+    is_template = True
+    parents = [OneOf(GandalfModelSpectrum, one2one=True)]
+    identifier_builder = ['gandalf_model_spectrum']
+
+
+class GandalfCleanIngestedSpectrum(GandalfDerivativeSpectrum):
     pass
 
-class GandalfEmissionModelSpectrum(GandalfModelSpectrum, GandalfSpectrum):
-    parents = [OneOf(GandalfModelSpectrum, one2one=True)]
-    identifier_builder = ['gandalf_model_spectrum']
 
-class GandalfCleanModelSpectrum(GandalfModelSpectrum, GandalfSpectrum):
-    parents = [OneOf(GandalfModelSpectrum, one2one=True)]
-    identifier_builder = ['gandalf_model_spectrum']
+class GandalfCleanModelSpectrum(GandalfDerivativeSpectrum):
+    pass
 
-class GandalfCleanIngestedSpectrum(GandalfModelSpectrum, GandalfSpectrum):
-    parents = [OneOf(CombinedIngestedSpectrum, one2one=True)]
-    identifier_builder = ['combined_ingested_spectrum']
+
+class GandalfEmissionModelSpectrum(GandalfDerivativeSpectrum):
+    pass
 
 
 class Fit(Hierarchy):
@@ -103,7 +111,7 @@ class Fit(Hierarchy):
     is_template = True
     parents = [Multiple(L1Spectrum, 2, 3, one2one=True),
                Multiple(UncombinedModelSpectrum, 0, 3, one2one=True),
-               Optional(CombinedModelSpectrum, one2one=True),
+               Optional(BaseCombinedModelSpectrum, one2one=True),
                Multiple(ModelSpectrum, 1, 3, one2one=True, notreal=True)]
 
 
@@ -113,7 +121,7 @@ class RedshiftArray(ArrayHolder):
 
 
 class Template(Fit):
-    parents = [Multiple(L1Spectrum, 2, 3, one2one=True),
+    parents = [Multiple(L1Spectrum, 2, 3),
                Multiple(UncombinedModelSpectrum, 0, 3, one2one=True), Optional(CombinedModelSpectrum, one2one=True),
                Multiple(ModelSpectrum, 1, 3, one2one=True, notreal=True)]
     factors = ['chi2_array', 'name']
@@ -124,9 +132,10 @@ class Template(Fit):
 class Redrock(Fit):
     factors = ['class', 'subclass', 'snr', 'chi2', 'deltachi2', 'ncoeff', 'coeff',
                'npixels', 'srvy_class', 'z', 'zerr', 'zwarn']
-    parents = [Multiple(L1Spectrum, 2, 3, one2one=True),
+    parents = [Multiple(L1Spectrum, 2, 3),
                Multiple(UncombinedModelSpectrum, 0, 3, one2one=True), Optional(CombinedModelSpectrum, one2one=True),
                Multiple(ModelSpectrum, 1, 3, one2one=True, notreal=True)]
+    # todo: really need to have a check in the merge that checks that combinedmodelspec doesnt exist if not given
     template_names = ['galaxy', 'qso', 'star_a', 'star_b', 'star_cv', 'star_f', 'star_g', 'star_k', 'star_m', 'star_wd']
     parents += [OneOf(Template, idname=x, one2one=True) for x in template_names]
     identifier_builder = ['uncombined_model_spectra', 'combined_model_spectrum']
@@ -134,7 +143,7 @@ class Redrock(Fit):
 
 class RVSpecfit(Fit):
     singular_name = 'rvspecfit'
-    parents = [Multiple(L1Spectrum, 2, 3, one2one=True),
+    parents = [Multiple(L1Spectrum, 2, 3),
                Multiple(UncombinedModelSpectrum, 0, 3, one2one=True), Optional(CombinedModelSpectrum, one2one=True),
                Multiple(ModelSpectrum, 1, 3, one2one=True, notreal=True)]
     factors = Fit.factors + ['skewness', 'kurtosis', 'vsini', 'snr', 'chi2_tot']
@@ -143,7 +152,7 @@ class RVSpecfit(Fit):
 
 
 class Ferre(Fit):
-    parents = [Multiple(L1Spectrum, 2, 3, one2one=True),
+    parents = [Multiple(L1Spectrum, 2, 3),
                Multiple(UncombinedModelSpectrum, 0, 3, one2one=True), Optional(CombinedModelSpectrum, one2one=True),
                Multiple(ModelSpectrum, 1, 3, one2one=True, notreal=True)]
     factors = Fit.factors + ['snr', 'chi2_tot', 'flag']
@@ -153,22 +162,28 @@ class Ferre(Fit):
 
 class Gandalf(Fit):
     plural_name = 'gandalfs'
-    parents = [Multiple(L1Spectrum, 2, 3, one2one=True), OneOf(GandalfModelSpectrum, one2one=True)]
+    parents = [Multiple(L1Spectrum, 2, 3),
+               OneOf(GandalfModelSpectrum, one2one=True, idname='model'),
+               OneOf(GandalfCleanIngestedSpectrum, one2one=True, idname='clean_observed'),
+               OneOf(GandalfCleanModelSpectrum, one2one=True, idname='clean_model'),
+               OneOf(GandalfEmissionModelSpectrum, one2one=True, idname='emission_line_model'),
+               ]
     factors = Fit.factors + ['fwhm_flag']
     factors += Line.as_factors(*gandalf_line_names) + SpectralIndex.as_factors(*gandalf_index_names)
-    identifier_builder = ['gandalf_model_spectrum']
+    identifier_builder = ['model']
 
 
 class PPXF(Fit):
-    parents = [Multiple(L1Spectrum, 2, 3, one2one=True), OneOf(CombinedModelSpectrum, one2one=True)]
-    factors = Fit.factors + MCMCMeasurement.as_factors('v', 'sigma', 'h3', 'h4', 'h5', 'h6') + Measurement.as_factors('zcorr')
+    parents = [Multiple(L1Spectrum, 2, 3), OneOf(CombinedModelSpectrum, one2one=True)]
+    factors = Fit.factors + MCMCMeasurement.as_factors('v', 'sigma', 'h3', 'h4', 'h5', 'h6') + \
+              Measurement.as_factors('zcorr')
     identifier_builder = ['combined_model_spectrum']
 
 
 class L2Product(L2):
     is_template = True
-    parents = [Multiple(L1Spectrum, 2, 3), APS,
-               OneOf(Redrock, one2one=True), Optional(RVSpecfit, one2one=True),
+    parents = [Multiple(L1Spectrum, 2, 3),
+               Optional(Redrock, one2one=True), Optional(RVSpecfit, one2one=True),
                Optional(Ferre, one2one=True), Optional(PPXF, one2one=True), Optional(Gandalf, one2one=True)]
 
 
